@@ -94,13 +94,14 @@
 
    o  SubRef class
 """
+from iaswn.iaswn import Iaswn
 
 # SubRef is a class with attributes and a .__init__() which fill automatically
 # the .int2char attribute.
 # pylint: disable=too-few-public-methods
 
 
-class SubRef:
+class SubRef(Iaswn):
     """
         SubRef class
 
